@@ -11,7 +11,7 @@ discretize <- function(x, ...)
 
 #' @rdname discretize
 discretize.default <- function(x, ...)
-  stop("Only numeric `x` is accepted")
+  rlang::abort("Only numeric `x` is accepted")
 
 #' @rdname discretize
 #' @param cuts An integer defining how many cuts to make of the
@@ -57,7 +57,8 @@ discretize.default <- function(x, ...)
 #' If `infs = FALSE` and a new value is greater than the
 #'  largest value of `x`, a missing value will result.
 #'@examples
-#'data(biomass)
+#' library(modeldata)
+#' data(biomass)
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training",]
 #' biomass_te <- biomass[biomass$dataset == "Testing",]
@@ -94,20 +95,21 @@ discretize.numeric <-
     missing_lab <- "_missing"
 
     if (cuts < 2)
-      stop("There should be at least 2 cuts")
+      rlang::abort("There should be at least 2 cuts")
 
     if (unique_vals / (cuts + 1) >= min_unique) {
       breaks <- quantile(x, probs = seq(0, 1, length = cuts + 1), ...)
       num_breaks <- length(breaks)
       breaks <- unique(breaks)
       if (num_breaks > length(breaks))
-        warning(
+        rlang::warn(
+          paste0(
           "Not enough data for ",
           cuts,
           " breaks. Only ",
           length(breaks),
-          " breaks were used.",
-          sep = ""
+          " breaks were used."
+          )
         )
       if (infs) {
         breaks[1] <- -Inf
@@ -118,12 +120,12 @@ discretize.numeric <-
       if (is.null(labels)) {
         prefix <- prefix[1]
         if (make.names(prefix) != prefix) {
-          warning(
+          rlang::warn(paste0(
             "The prefix '",
             prefix,
             "' is not a valid R name. It has been changed to '",
             make.names(prefix),
-            "'."
+            "'.")
           )
           prefix <- make.names(prefix)
         }
@@ -141,8 +143,12 @@ discretize.numeric <-
       )
     } else {
       out <- list(bins = 0)
-      warning("Data not binned; too few unique values per bin. ",
-              "Adjust 'min_unique' as needed", call. = FALSE)
+      rlang::warn(
+        paste0(
+          "Data not binned; too few unique values per bin. ",
+          "Adjust 'min_unique' as needed"
+        )
+      )
     }
     class(out) <- "discretize"
     out
@@ -298,8 +304,12 @@ prep.step_discretize <- function(x, training, info = NULL, ...) {
   check_type(training[, col_names])
 
   if (length(col_names) > 1 & any(names(x$options) %in% c("prefix", "labels"))) {
-    warning("Note that the options `prefix` and `labels`",
-            "will be applied to all variables")
+    rlang::warn(
+      paste0(
+        "Note that the options `prefix` and `labels`",
+        "will be applied to all variables"
+      )
+    )
   }
 
   x$options$cuts <- x$num_breaks
