@@ -59,10 +59,12 @@ step_holiday <-
     skip = FALSE,
     id = rand_id("holiday")
   ) {
-  all_days <- listHolidays()
-  if (!all(holidays %in% all_days))
-    stop("Invalid `holidays` value. See timeDate::listHolidays",
-         call. = FALSE)
+
+    if (!is_tune(holidays) & !is_varying(holidays)) {
+      all_days <- listHolidays()
+      if (!all(holidays %in% all_days))
+        rlang::abort("Invalid `holidays` value. See timeDate::listHolidays")
+    }
 
   add_step(
     recipe,
@@ -92,15 +94,18 @@ step_holiday_new <-
     )
   }
 
-#' @importFrom stats as.formula model.frame
 #' @export
 prep.step_holiday <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
 
   holiday_data <- info[info$variable %in% col_names, ]
   if (any(holiday_data$type != "date"))
-    stop("All variables for `step_holiday` should be either `Date` ",
-         "or `POSIXct` classes.", call. = FALSE)
+    rlang::abort(
+      paste0(
+        "All variables for `step_holiday` should be either `Date` ",
+        "or `POSIXct` classes."
+         )
+    )
 
   step_holiday_new(
     terms = x$terms,
@@ -122,7 +127,6 @@ is_holiday <- function(hol, dt) {
   out
 }
 
-#' @importFrom lubridate year is.Date
 get_holiday_features <- function(dt, hdays) {
   if (!is.Date(dt))
     dt <- as.Date(dt)
@@ -133,7 +137,6 @@ get_holiday_features <- function(dt, hdays) {
   as_tibble(hfeat)
 }
 
-#' @importFrom tibble as_tibble is_tibble
 #' @export
 bake.step_holiday <- function(object, new_data, ...) {
   new_cols <-
