@@ -11,7 +11,7 @@
 #'  [selections()] for more details. For the `tidy`
 #'  method, these are not currently used.
 #' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
+#'  role should they be assigned? By default, the function assumes
 #'  that the new principal component columns created by the original
 #'  variables will be used as predictors in a model.
 #' @param num_comp The number of PCA components to retain as new
@@ -170,7 +170,8 @@ prep.step_kpca_rbf <- function(x, training, info = NULL, ...) {
       )
 
     if (inherits(kprc, "try-error")) {
-      stop("`step_kpca_rbf` failed with error:\n", as.character(kprc), call. = FALSE)
+      rlang::abort(paste0("`step_kpca_rbf` failed with error:\n",
+                          as.character(kprc)))
     }
   } else {
     kprc <- list(x_vars = col_names)
