@@ -15,12 +15,13 @@
 #' have been resolved by [prep()].
 #' @param columns A character string of variable names that will
 #'  be populated (eventually) by the terms argument.
+#' @param id A character string that is unique to this step to identify it.
 #' @param skip A logical. Should the check be skipped when the
 #'  recipe is baked by [bake.recipe()]? While all operations are baked
 #'  when [prep.recipe()] is run, some operations may not be able to be
 #'  conducted on new data (e.g. processing the outcome variable(s)).
 #'  Care should be taken when using `skip = TRUE` as it may affect
-#'  the computations for subsequent operations. 
+#'  the computations for subsequent operations.
 #' @return An updated version of `recipe` with the new check
 #'  added to the sequence of existing operations (if any). For the
 #'  `tidy` method, a tibble with columns `terms` (the
@@ -30,10 +31,11 @@
 #'  columns does contain `NA` values. If the check passes, nothing is changed
 #'  to the data.
 #' @examples
+#' library(modeldata)
 #' data(credit_data)
 #' is.na(credit_data) %>% colSums()
 #'
-#' # If the test passes, newdata is returned unaltered
+#' # If the test passes, `new_data` is returned unaltered
 #' recipe(credit_data) %>%
 #'   check_missing(Age, Expenses) %>%
 #'   prep() %>%
@@ -47,7 +49,7 @@
 #'   prep()
 #' }
 #'
-#' # If newdata contain missing values, the check will stop bake()
+#' # If `new_data` contain missing values, the check will stop bake()
 #'
 #' train_data <- credit_data %>% dplyr::filter(Income > 150)
 #' test_data  <- credit_data %>% dplyr::filter(Income <= 150 | is.na(Income))
@@ -66,7 +68,8 @@ check_missing <-
            role = NA,
            trained = FALSE,
            columns = NULL,
-           skip = FALSE) {
+           skip = FALSE,
+           id = rand_id("missing")) {
     add_check(
       recipe,
       check_missing_new(
@@ -74,24 +77,22 @@ check_missing <-
         role    = role,
         trained = trained,
         columns = columns,
-        skip = skip
+        skip = skip,
+        id = id
       )
     )
   }
 
 check_missing_new <-
-  function(terms = NULL,
-           role  = NA,
-           trained = FALSE,
-           columns = NULL,
-           skip = FALSE) {
+  function(terms, role, trained, columns, skip, id) {
     check(subclass = "missing",
           prefix   = "check_",
           terms    = terms,
           role     = role,
           trained  = trained,
           columns  = columns,
-          skip = skip)
+          skip     = skip,
+          id       = id)
   }
 
 prep.check_missing <- function(x, training, info = NULL, ...) {
@@ -100,20 +101,21 @@ prep.check_missing <- function(x, training, info = NULL, ...) {
                     role  = x$role,
                     trained = TRUE,
                     columns = col_names,
-                    skip = x$skip)
+                    skip = x$skip,
+                    id = x$id)
 }
 
-bake.check_missing <- function(object, newdata, ...) {
+bake.check_missing <- function(object, new_data, ...) {
   col_names       <- object$columns
-  subset_to_check <- newdata[col_names]
+  subset_to_check <- new_data[col_names]
   nr_na           <- colSums(is.na(subset_to_check))
   if (any(nr_na > 0)) {
     with_na     <- names(nr_na[nr_na > 0])
     with_na_str <- paste(paste0("`", with_na, "`"), collapse = ", ")
-    stop("The following columns contain missing values: ",
-         with_na_str, ".", call. = FALSE)
+    rlang::abort(paste0("The following columns contain missing values: ",
+                        with_na_str, "."))
   }
-  newdata
+  new_data
 }
 
 print.check_missing <-
@@ -125,11 +127,13 @@ print.check_missing <-
 
 #' @rdname check_missing
 #' @param x A `check_missing` object.
+#' @export
 tidy.check_missing <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(terms = x$columns)
   } else {
     res <- tibble(terms = sel2char(x$terms))
   }
+  res$id <- x$id
   res
 }
