@@ -95,7 +95,7 @@ bake.step_mutate_at <- function(object, new_data, ...) {
 print.step_mutate_at <-
   function(x, width = max(20, options()$width - 35), ...) {
     cat("Variable mutation for ", sep = "")
-    printer(names(x$means), x$terms, x$trained, width = width)
+    printer(x$inputs, x$terms, x$trained, width = width)
     invisible(x)
   }
 
