@@ -54,13 +54,14 @@
 #'
 #' @examples
 #'
+#' library(modeldata)
 #' data(biomass)
 #'
 #' # rec <- recipe(HHV ~ ., data = biomass) %>%
 #' #   update_role(sample, new_role = "id var") %>%
 #' #   update_role(dataset, new_role = "split variable") %>%
 #' #   step_nnmf(all_predictors(), num_comp = 2, seed = 473, num_run = 2) %>%
-#' #   prep(training = biomass, retain = TRUE)
+#' #   prep(training = biomass)
 #' #
 #' # juice(rec)
 #' #
@@ -149,7 +150,7 @@ prep.step_nnmf <- function(x, training, info = NULL, ...) {
 
     nnm <- try(do.call(dimRed::embed, opts), silent = TRUE)
     if (inherits(nnm, "try-error")) {
-      stop("`step_nnmf` failed with error:\n", as.character(nnm), call. = FALSE)
+      rlang::abort(paste0("`step_nnmf` failed with error:\n", as.character(nnm)))
     }
   } else {
     nnm <- list(x_vars = col_names)
