@@ -54,6 +54,7 @@
 #'  names would be `PLS001` - `PLS101`.
 #'
 #' @examples
+#' library(modeldata)
 #' data(biomass)
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training",]
@@ -68,7 +69,7 @@
 #'   step_normalize(all_outcomes(), skip = TRUE) %>%
 #'   step_pls(all_predictors(), outcome = "HHV")
 #'
-#' pls_rec <- prep(pls_rec, training = biomass_tr, retain = TRUE)
+#' pls_rec <- prep(pls_rec, training = biomass_tr)
 #'
 #' pls_test_scores <- bake(pls_rec, new_data = biomass_te[, -8])
 #'
@@ -90,7 +91,7 @@ step_pls <-
            skip = FALSE,
            id = rand_id("pls")) {
     if (is.null(outcome))
-      stop("`outcome` should select at least one column.", call. = FALSE)
+      rlang::abort("`outcome` should select at least one column.")
 
     recipes_pkg_check("pls")
 
