@@ -15,7 +15,7 @@ recipe <- function(x, ...)
 #' @rdname recipe
 #' @export
 recipe.default <- function(x, ...)
-  stop("`x` should be a data frame, matrix, or tibble", call. = FALSE)
+  rlang::abort("`x` should be a data frame, matrix, or tibble")
 
 #' @rdname recipe
 #' @param vars A character string of column names corresponding to variables
@@ -27,10 +27,10 @@ recipe.default <- function(x, ...)
 #' @param ... Further arguments passed to or from other methods (not currently
 #'   used).
 #' @param formula A model formula. No in-line functions should be used here
-#'   (e.g. `log(x)`, `x:y`, etc.). These types of transformations
-#'   should be enacted using `step` functions in this package. Dots are
-#'   allowed as are simple multivariate outcome terms (i.e. no need for
-#'   `cbind`; see Examples).
+#'  (e.g. `log(x)`, `x:y`, etc.) and minus signs are not allowed. These types of
+#'  transformations should be enacted using `step` functions in this package.
+#'  Dots are allowed as are simple multivariate outcome terms (i.e. no need for
+#'  `cbind`; see Examples).
 #' @param x,data A data frame or tibble of the *template* data set
 #'   (see below).
 #' @return An object of class `recipe` with sub-objects:
@@ -90,6 +90,7 @@ recipe.default <- function(x, ...)
 #'
 #' ###############################################
 #' # simple example:
+#' library(modeldata)
 #' data(biomass)
 #'
 #' # split data
@@ -153,11 +154,17 @@ recipe.data.frame <-
 
     if (!is.null(formula)) {
       if (!is.null(vars))
-        stop("This `vars` specification will be ignored when a formula is ",
-             "used", call. = FALSE)
+        rlang::abort(
+          paste0("This `vars` specification will be ignored ",
+             "when a formula is used"
+             )
+          )
       if (!is.null(roles))
-        stop("This `roles` specification will be ignored when a formula is ",
-             "used", call. = FALSE)
+        rlang::abort(
+          paste0("This `roles` specification will be ignored ",
+             "when a formula is used"
+             )
+          )
 
       obj <- recipe.formula(formula, x, ...)
       return(obj)
@@ -170,9 +177,9 @@ recipe.data.frame <-
       x <- as_tibble(x)
 
     if (any(table(vars) > 1))
-      stop("`vars` should have unique members", call. = FALSE)
+      rlang::abort("`vars` should have unique members")
     if (any(!(vars %in% colnames(x))))
-      stop("1+ elements of `vars` are not in `x`", call. = FALSE)
+      rlang::abort("1+ elements of `vars` are not in `x`")
 
     x <- x[, vars]
 
@@ -181,8 +188,10 @@ recipe.data.frame <-
     ## Check and add roles when available
     if (!is.null(roles)) {
       if (length(roles) != length(vars))
-        stop("The number of roles should be the same as the number of ",
-             "variables", call. = FALSE)
+        rlang::abort(
+          paste0("The number of roles should be the same as the number of ",
+             "variables")
+        )
       var_info$role <- roles
     } else
       var_info$role <- NA
@@ -207,6 +216,13 @@ recipe.data.frame <-
 #' @rdname recipe
 #' @export
 recipe.formula <- function(formula, data, ...) {
+  # check for minus:
+  f_funcs <- fun_calls(formula)
+  if (any(f_funcs == "-")) {
+    rlang::abort("`-` is not allowed in a recipe formula. Use `step_rm()` instead.")
+  }
+
+  # Check for other in-line functions
   args <- form2args(formula, data, ...)
   obj <- recipe.data.frame(
     x = args$x,
@@ -329,13 +345,19 @@ prep.recipe <-
 
     if (is.null(training)) {
       if (fresh)
-        stop("A training set must be supplied to the `training` argument ",
-             "when `fresh = TRUE`", call. = FALSE)
+        rlang::abort(
+          paste0("A training set must be supplied to the `training` argument ",
+             "when `fresh = TRUE`"
+             )
+          )
       training <- x$template
     } else {
       if (!all(vars %in% colnames(training))) {
-        stop("Not all variables in the recipe are present in the supplied ",
-             "training set", call. = FALSE)
+        rlang::abort(
+          paste0("Not all variables in the recipe are present in the supplied ",
+             "training set"
+          )
+        )
       }
       training <- if (!is_tibble(training))
         as_tibble(training[, vars, drop = FALSE])
@@ -346,18 +368,20 @@ prep.recipe <-
     steps_trained <- vapply(x$steps, is_trained, logical(1))
     if (any(steps_trained) & !fresh) {
       if(!x$retained)
-        stop(
+        rlang::abort(
+          paste0(
           "To prep new steps after prepping the original ",
           "recipe, `retain = TRUE` must be set each time that ",
-          "the recipe is trained.",
-          call. = FALSE
+          "the recipe is trained."
+          )
         )
       if (!is.null(x$training))
-        warning(
-          "The previous data will be used by `prep`; ",
-          "the data passed using `training` will be ",
-          "ignored.",
-          call. = FALSE
+        rlang::warn(
+          paste0(
+            "The previous data will be used by `prep`; ",
+            "the data passed using `training` will be ",
+            "ignored."
+          )
         )
       training <- x$template
     }
@@ -378,9 +402,13 @@ prep.recipe <-
     # use `retain = TRUE` so issue a warning if this is not the case
     skippers <- map_lgl(x$steps, is_skipable)
     if (any(skippers) & !retain)
-      warning("Since some operations have `skip = FALSE`, using ",
-              "`retain = TRUE` will allow those steps results to ",
-              "be accessible.")
+      rlang::warn(
+        paste0(
+          "Since some operations have `skip = FALSE`, using ",
+          "`retain = TRUE` will allow those steps results to ",
+          "be accessible."
+        )
+      )
 
 
     running_info <- x$term_info %>% mutate(number = 0, skip = FALSE)
@@ -506,15 +534,16 @@ bake <- function(object, ...)
 #' @export
 bake.recipe <- function(object, new_data = NULL, ..., composition = "tibble") {
   if (!fully_trained(object)) {
-    stop("At least one step has not been trained. Please ",
-         "run `prep`.",
-         call. = FALSE)
+    rlang::abort("At least one step has not been trained. Please run `prep`.")
   }
 
   if (!any(composition == formats)) {
-    stop("`composition` should be one of: ",
-         paste0("'", formats, "'", collapse = ","),
-         call. = FALSE)
+    rlang::abort(
+      paste0(
+      "`composition` should be one of: ",
+      paste0("'", formats, "'", collapse = ",")
+      )
+    )
   }
 
   terms <- quos(...)
@@ -525,10 +554,9 @@ bake.recipe <- function(object, new_data = NULL, ..., composition = "tibble") {
   # In case someone used the deprecated `newdata`:
   if (is.null(new_data) || is.null(ncol(new_data))) {
     if (any(names(terms) == "newdata")) {
-      stop("Please use `new_data` instead of `newdata` with `bake`.",
-           call. = FALSE)
+      rlang::abort("Please use `new_data` instead of `newdata` with `bake`.")
     } else {
-      stop("Please pass a data set to `new_data`.", call. = FALSE)
+      rlang::abort("Please pass a data set to `new_data`.")
     }
   }
 
@@ -566,6 +594,9 @@ bake.recipe <- function(object, new_data = NULL, ..., composition = "tibble") {
     }
 
     new_data <- new_data[, names(new_data) %in% keepers]
+    columns_sorted <- match(keepers, names(new_data))
+    columns_sorted <- columns_sorted[!is.na(columns_sorted)]
+    new_data <- new_data[, columns_sorted]
     ## The levels are not null when no nominal data are present or
     ## if strings_as_factors = FALSE in `prep`
     if (!is.null(object$levels)) {
@@ -579,7 +610,7 @@ bake.recipe <- function(object, new_data = NULL, ..., composition = "tibble") {
         new_data <- strings2factors(new_data, var_levels)
     }
   } else {
-    new_data <- tibble()
+    new_data <- tibble(.rows = nrow(new_data))
   }
 
   if (composition == "dgCMatrix") {
@@ -696,6 +727,7 @@ summary.recipe <- function(object, original = FALSE, ...) {
 #'  the step's `skip` argument.
 #'
 #' @examples
+#' library(modeldata)
 #' data(biomass)
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training",]
@@ -708,7 +740,7 @@ summary.recipe <- function(object, original = FALSE, ...) {
 #'   step_normalize(all_predictors()) %>%
 #'   step_spatialsign(all_predictors())
 #'
-#' sp_signed_trained <- prep(sp_signed, training = biomass_tr, retain = TRUE)
+#' sp_signed_trained <- prep(sp_signed, training = biomass_tr)
 #'
 #' tr_values <- bake(sp_signed_trained, new_data = biomass_tr, all_predictors())
 #' og_values <- juice(sp_signed_trained, all_predictors())
@@ -718,20 +750,23 @@ summary.recipe <- function(object, original = FALSE, ...) {
 #' @seealso [recipe()] [prep.recipe()] [bake.recipe()]
 juice <- function(object, ..., composition = "tibble") {
   if (!fully_trained(object)) {
-    stop("At least one step has not been trained. Please ",
-         "run `prep`.",
-         call. = FALSE)
+    rlang::abort("At least one step has not been trained. Please run `prep`.")
   }
 
   if (!isTRUE(object$retained)) {
-    stop("Use `retain = TRUE` in `prep` to be able to extract the training set",
-         call. = FALSE)
+    rlang::abort(
+      paste0("Use `retain = TRUE` in `prep` to be able",
+             "to extract the training set"
+             )
+    )
   }
 
   if (!any(composition == formats)) {
-    stop("`composition` should be one of: ",
-         paste0("'", formats, "'", collapse = ","),
-         call. = FALSE)
+    rlang::abort(
+      paste0("`composition` should be one of: ",
+         paste0("'", formats, "'", collapse = ",")
+         )
+      )
   }
 
   terms <- quos(...)
@@ -758,7 +793,7 @@ juice <- function(object, ..., composition = "tibble") {
         new_data <- strings2factors(new_data, var_levels)
     }
   } else {
-    new_data <- tibble()
+    new_data <- tibble(.rows = nrow(object$template))
   }
 
   if (composition == "dgCMatrix") {
