@@ -56,6 +56,7 @@
 #' @concept subsampling
 #' @export
 #' @examples
+#' library(modeldata)
 #' data(okc)
 #'
 #' orig <- table(okc$diet, useNA = "always")
@@ -66,7 +67,7 @@
 #'   # Bring the minority levels up to about 200 each
 #'   # 200/16562 is approx 0.0121
 #'   step_upsample(diet, over_ratio = 0.0121) %>%
-#'   prep(training = okc, retain = TRUE)
+#'   prep(training = okc)
 #'
 #' training <- table(juice(up_rec)$diet, useNA = "always")
 #'
@@ -138,9 +139,9 @@ step_upsample_new <-
 prep.step_upsample <- function(x, training, info = NULL, ...) {
   col_name <- terms_select(x$terms, info = info)
   if (length(col_name) != 1)
-    stop("Please select a single factor variable.", call. = FALSE)
+    rlang::abort("Please select a single factor variable.")
   if (!is.factor(training[[col_name]]))
-    stop(col_name, " should be a factor variable.", call. = FALSE)
+    rlang::abort(col_name, " should be a factor variable.")
 
 
   obs_freq <- table(training[[col_name]])
