@@ -1,4 +1,4 @@
-## ----ex_setup, include=FALSE---------------------------------------------
+## ----ex_setup, include=FALSE--------------------------------------------------
 knitr::opts_chunk$set(
   message = FALSE,
   digits = 3,
@@ -7,25 +7,26 @@ knitr::opts_chunk$set(
   )
 options(digits = 3)
 
-## ----step_list-----------------------------------------------------------
+## ----step_list----------------------------------------------------------------
 library(recipes)
 ls("package:recipes", pattern = "^step_")
 
-## ----initial-------------------------------------------------------------
+## ----initial------------------------------------------------------------------
+library(modeldata)
 data(biomass)
 str(biomass)
 
 biomass_tr <- biomass[biomass$dataset == "Training",]
 biomass_te <- biomass[biomass$dataset == "Testing",]
 
-## ----carbon_dist, fig.width=6, fig.height=4.25,  out.width = '100%'------
+## ----carbon_dist, fig.width=6, fig.height=4.25,  out.width = '100%'-----------
 library(ggplot2)
 theme_set(theme_bw())
 ggplot(biomass_tr, aes(x = carbon)) + 
   geom_histogram(binwidth = 5, col = "blue", fill = "blue", alpha = .5) + 
   geom_vline(xintercept = biomass_te$carbon[1], lty = 2)
 
-## ----initial_def---------------------------------------------------------
+## ----initial_def--------------------------------------------------------------
 step_percentile <- function(
   recipe, ..., 
   role = NA, 
@@ -33,13 +34,15 @@ step_percentile <- function(
   ref_dist = NULL,
   approx = FALSE, 
   options = list(probs = (0:100)/100, names = TRUE),
-  skip = FALSE
+  skip = FALSE,
+  id = rand_id("percentile")
   ) {
-## The variable selectors are not immediately evaluated by using
-## the `quos` function in `rlang`
-  terms <- rlang::quos(...) 
-  if(length(terms) == 0)
-    stop("Please supply at least one variable specification. See ?selections.")
+
+  ## The variable selectors are not immediately evaluated by using
+  ##  the `quos` function in `rlang`. `ellipse_check` captures the
+  ##  values and also checks to make sure that they are not empty.  
+  terms <- ellipse_check(...) 
+
   add_step(
     recipe, 
     step_percentile_new(
@@ -49,37 +52,34 @@ step_percentile <- function(
       ref_dist = ref_dist,
       approx = approx,
       options = options,
-      skip = skip))
-}
-
-## ----initialize----------------------------------------------------------
-step_percentile_new <- function(
-  terms = NULL, 
-  role = NA, 
-  trained = FALSE, 
-  ref_dist = NULL, 
-  approx = NULL, 
-  options = NULL,
-  skip = FALSE
-) {
-  step(
-    subclass = "percentile", 
-    terms = terms,
-    role = role,
-    trained = trained,
-    ref_dist = ref_dist,
-    approx = approx,
-    options = options,
-    skip = skip
+      skip = skip,
+      id = id
+    )
   )
 }
 
-## ----prep_1, eval = FALSE------------------------------------------------
+## ----initialize---------------------------------------------------------------
+step_percentile_new <- 
+  function(terms, role, trained, ref_dist, approx, options, skip, id) {
+    step(
+      subclass = "percentile", 
+      terms = terms,
+      role = role,
+      trained = trained,
+      ref_dist = ref_dist,
+      approx = approx,
+      options = options,
+      skip = skip,
+      id = id
+    )
+  }
+
+## ----prep_1, eval = FALSE-----------------------------------------------------
 #  prep.step_percentile <- function(x, training, info = NULL, ...) {
 #    col_names <- terms_select(terms = x$terms, info = info)
 #  }
 
-## ----prep_2--------------------------------------------------------------
+## ----prep_2-------------------------------------------------------------------
 get_pctl <- function(x, args) {
   args$x <- x
   do.call("quantile", args)
@@ -87,25 +87,21 @@ get_pctl <- function(x, args) {
 
 prep.step_percentile <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(terms = x$terms, info = info) 
-  ## You can add error trapping for non-numeric data here and so on.
-  ## We'll use the names later so
-  if(x$options$names == FALSE)
-    stop("`names` should be set to TRUE", call. = FALSE)
+  ## You can add error trapping for non-numeric data here and so on. See the
+  ## `check_type` function to do this for basic types. 
   
-  if(!x$approx) {
+  ## We'll use the names later so
+  if (x$options$names == FALSE)
+    rlang::abort("`names` should be set to TRUE")
+  
+  if (!x$approx) {
     ref_dist <- training[, col_names]
   } else {
-    pctl <- lapply(
-      training[, col_names],  
-      get_pctl, 
-      args = x$options
-    )
-    ref_dist <- pctl
+    ref_dist <- purrr::map(training[, col_names],  get_pctl, args = x$options)
   }
 
-  ## It is a good idea to use the constructor function
-  ## to return the updated object. Note that `trained` is
-  ## set to TRUE
+  ## Use the constructor function to return the updated object. 
+  ## Note that `trained` is set to TRUE
   
   step_percentile_new(
     terms = x$terms, 
@@ -114,11 +110,12 @@ prep.step_percentile <- function(x, training, info = NULL, ...) {
     ref_dist = ref_dist,
     approx = x$approx,
     options = x$options,
-    skip = x$skip
+    skip = x$skip,
+    id = x$id
   )
 }
 
-## ----bake----------------------------------------------------------------
+## ----bake---------------------------------------------------------------------
 ## Two helper functions
 pctl_by_mean <- function(x, ref) mean(ref <= x)
 
@@ -130,30 +127,30 @@ pctl_by_approx <- function(x, ref) {
   approx(x = ref, y = p_grid, xout = x)$y/100
 }
 
-bake.step_percentile <- function(object, newdata, ...) {
+bake.step_percentile <- function(object, new_data, ...) {
   require(tibble)
   ## For illustration (and not speed), we will loop through the affected variables
   ## and do the computations
   vars <- names(object$ref_dist)
   
-  for(i in vars) {
-    if(!object$approx) {
+  for (i in vars) {
+    if (!object$approx) {
       ## We can use `apply` since tibbles do not drop dimensions:
-      newdata[, i] <- apply(newdata[, i], 1, pctl_by_mean, 
+      new_data[, i] <- apply(new_data[, i], 1, pctl_by_mean, 
                             ref = object$ref_dist[, i])
     } else 
-      newdata[, i] <- pctl_by_approx(newdata[, i], object$ref_dist[[i]])
+      new_data[, i] <- pctl_by_approx(new_data[, i], object$ref_dist[[i]])
   }
   ## Always convert to tibbles on the way out
-  as_tibble(newdata)
+  as_tibble(new_data)
 }
 
-## ----example-------------------------------------------------------------
-rec_obj <- recipe(HHV ~ ., data = biomass_tr[, -(1:2)])
-rec_obj <- rec_obj %>%
-  step_percentile(all_predictors(), approx = TRUE) 
-
-rec_obj <- prep(rec_obj, training = biomass_tr)
+## ----example------------------------------------------------------------------
+library(purrr)
+rec_obj <- 
+  recipe(HHV ~ ., data = biomass_tr[, -(1:2)]) %>%
+  step_percentile(all_predictors(), approx = TRUE) %>%
+  prep(training = biomass_tr)
 
 percentiles <- bake(rec_obj, biomass_te)
 percentiles
